@@ -1,13 +1,16 @@
 from projectal.entity import Entity
 from projectal import api
+from projectal.linkers import *
 
 
-class Contact(Entity):
+class Contact(Entity, CompanyLinker, CustomerLinker, NoteLinker):
     """
     Implementation of the [Contact](https://projectal.com/docs/latest/#tag/Contact) API.
     """
     _path = 'contact'
-    _name = 'CONTACT'
+    _name = 'contact'
+    _links = [NoteLinker]
+    _links_reverse = [CompanyLinker, CustomerLinker]
 
     @classmethod
     def create(cls, holder, entity):
