@@ -3,12 +3,23 @@ from projectal.linkers import *
 from projectal import api
 
 
-class Folder(Entity, FolderLinker, FileLinker):
+class Folder(Entity, FileLinker, FolderLinker, NoteLinker):
     """
     Implementation of the [Folder](https://projectal.com/docs/latest/#tag/Folder) API.
     """
     _path = 'folder'
-    _name = 'STORAGE_FOLDER'
+    _name = 'folder'
+    _links = [FileLinker, FolderLinker, NoteLinker]
+
+    def __init__(self, data):
+        super().__init__(data)
+
+        # TODO: override linker definition here due to differences in list name vs other file linkers.
+        # Remove if/when API is changed to address this.
+        class CustomFile(BaseLinker):
+            _link_name = 'file'
+            _link_key = 'files'
+        self._add_link_def(CustomFile)
 
     @classmethod
     def create(cls, entity):
@@ -19,8 +30,13 @@ class Folder(Entity, FolderLinker, FileLinker):
         return cls(entity)
 
     @classmethod
-    def get(cls, uuId):
-        return cls(api.get('/api/folder/get?uuId={}'.format(uuId)))
+    def get(cls, uuId, links=None):
+        """Get the File entity. No file data is included."""
+        link_set = cls._get_linkset(links)
+        url = '/api/folder/get?uuId={}'.format(uuId)
+        if link_set:
+            url += '&links=' + ','.join(link_set)
+        return cls(api.get(url))
 
     @classmethod
     def update(cls, entity):
@@ -33,13 +49,6 @@ class Folder(Entity, FolderLinker, FileLinker):
         api.delete('/api/folder/delete/{}'.format(uuId))
         return True
 
-    # TODO: reimplemented here due to differences in list name vs other file linkers.
-    # Remove in future if/when api is fixed
-    def link_file(self, file):
-        self._add_link(self, 'file', [file], list_name='files')
-
-    def unlink_file(self,  file):
-        self._delete_link(self, 'file', [file], list_name='files')
 
     @classmethod
     def list(cls, expand=True):
