@@ -1,20 +1,21 @@
 from datetime import datetime
 
 import projectal
-
 from projectal.entity import Entity
-from projectal import api
+from projectal.linkers import *
 
 
-class Location(Entity):
+class Location(Entity, CompanyLinker, CustomerLinker, ProjectLinker, StaffLinker,
+               NoteLinker, CalendarLinker):
     """
     Implementation of the [Location](https://projectal.com/docs/latest/#tag/Location) API.
     """
     _path = 'location'
-    _name = 'LOCATION'
+    _name = 'location'
+    _links = [NoteLinker, CalendarLinker]
+    _links_reverse = [CompanyLinker, CustomerLinker, ProjectLinker, StaffLinker]
 
-    @classmethod
-    def calendar(cls, uuId, begin=None, until=None):
+    def calendar(self, begin=None, until=None):
         """
         Get the location's calendar.
         `uuId`: The location `uuId`
@@ -26,7 +27,7 @@ class Location(Entity):
         if until:
             until = datetime.strptime(until, '%Y-%m-%d').date()
 
-        url = '/api/location/{}/calendar?'.format(uuId)
+        url = '/api/location/{}/calendar?'.format(self['uuId'])
         params = []
         params.append('begin={}'.format(begin)) if begin else None
         params.append('until={}'.format(until)) if until else None
