@@ -3,13 +3,16 @@ from projectal.linkers import *
 from projectal import api
 
 
-class Project(Entity, CustomerLinker, FileLinker, LocationLinker, RebateLinker,
-              StageLinker, StageListLinker):
+class Project(Entity,  LocationLinker, CustomerLinker, FileLinker, StageLinker,
+              RebateLinker, StageListLinker, CompanyLinker, NoteLinker):
     """
     Implementation of the [Project](https://projectal.com/docs/latest/#tag/Project) API.
     """
     _path = 'project'
-    _name = 'PROJECT'
+    _name = 'project'
+    _links = [LocationLinker, CustomerLinker, FileLinker, StageLinker,
+              RebateLinker, StageListLinker, NoteLinker]
+    _links_reverse = [CompanyLinker]
 
     @classmethod
     def stage_order(cls, uuId, stages):
