@@ -1,14 +1,15 @@
 from projectal import api
 from projectal.entity import Entity
+from projectal.linkers import *
 
-
-class ProjectTemplate(Entity):
+class ProjectTemplate(Entity, NoteLinker):
     """
     Implementation of the
     [Project Template](https://projectal.com/docs/latest/#tag/Project-Template) API.
     """
     _path = 'template/project'
-    _name = 'PROJECT_TEMPLATE'
+    _name = 'project_template'
+    _links = [NoteLinker]
 
     @classmethod
     def autoschedule(cls, project, mode='ASAP'):
