@@ -1,17 +1,20 @@
 from datetime import datetime
 
 import projectal
-from projectal import api
 from projectal.entity import Entity
 from projectal.linkers import *
 
 
-class Staff(Entity, FileLinker, LocationLinker, SkillLinker):
+class Staff(Entity, LocationLinker, ResourceLinker, SkillLinker, FileLinker,
+            CompanyLinker, DepartmentLinker, TaskLinker, TaskTemplateLinker,
+            NoteLinker, CalendarLinker):
     """
     Implementation of the [Staff](https://projectal.com/docs/latest/#tag/Staff) API.
     """
     _path = 'staff'
-    _name = 'STAFF'
+    _name = 'staff'
+    _links = [LocationLinker, ResourceLinker, SkillLinker, FileLinker, NoteLinker, CalendarLinker]
+    _links_reverse = [CompanyLinker, DepartmentLinker, TaskLinker, TaskTemplateLinker]
 
     @classmethod
     def calendar(cls, uuId, begin=None, until=None):
