@@ -1,9 +1,11 @@
 from projectal.entity import Entity
+from projectal.linkers import *
 
 
-class Stage(Entity):
+class Stage(Entity, ProjectLinker, TaskLinker):
     """
     Implementation of the [Stage](https://projectal.com/docs/latest/#tag/Stage) API.
     """
     _path = 'stage'
-    _name = 'STAGE'
+    _name = 'stage'
+    _links_reverse = [ProjectLinker, TaskLinker]
