@@ -1,15 +1,17 @@
+from projectal import api
 from projectal.entity import Entity
 from projectal.linkers import *
-from projectal import api
 
 
-class TaskTemplate(Entity, FileLinker, RebateLinker, SkillLinker, StaffLinker):
+class TaskTemplate(Entity, ResourceLinker, SkillLinker, FileLinker, StaffLinker, RebateLinker,
+                   NoteLinker):
     """
     Implementation of the
     [Task Template](https://projectal.com/docs/latest/#tag/Task-Template) API.
     """
     _path = 'template/task'
-    _name = 'TASK_TEMPLATE'
+    _name = 'task_template'
+    _links = [ResourceLinker, SkillLinker, FileLinker, StaffLinker, RebateLinker, NoteLinker]
 
     def clone(self, holder, entity):
         url = '/api/template/task/clone?holder={}&reference={}'\
